@@ -80,10 +80,7 @@ gvisWelcomeMessage <- function(){
         "More information is available on the googleVis project web-site:\n",
         "http://code.google.com/p/google-motion-charts-with-r/\n",
         "\n",               
-        "Feel free to send us an email <rvisualisation@gmail.com>\n",
-        "if you would like to be keept informed of new versions,\n",
-        "or if you have any feedback, ideas, suggestions or would\n",
-        "like to collaborate.\n",
+        "Contact: <rvisualisation@gmail.com>\n",
         "\n",
         "To suppress the this message use:\n",
         "suppressPackageStartupMessages(library(googleVis))\n",  
